Exceptions
==========

These are all errors that can be reported by API requests. These errors mirror
those used in the REST API.

.. automodule:: brainframe.api.bf_errors
   :members:
   :exclude-members: kind_to_error_type
